@@ -2,9 +2,9 @@ import typing_extensions
 
 from openapi_aptos_api.apis.tags import TagValues
 from openapi_aptos_api.apis.tags.accounts_api import AccountsApi
+from openapi_aptos_api.apis.tags.blocks_api import BlocksApi
 from openapi_aptos_api.apis.tags.coins_api import CoinsApi
 from openapi_aptos_api.apis.tags.collections_api import CollectionsApi
-from openapi_aptos_api.apis.tags.default_api import DefaultApi
 from openapi_aptos_api.apis.tags.nfts_api import NftsApi
 from openapi_aptos_api.apis.tags.transactions_api import TransactionsApi
 from openapi_aptos_api.apis.tags.wallets_api import WalletsApi
@@ -13,9 +13,9 @@ TagToApi = typing_extensions.TypedDict(
     'TagToApi',
     {
         TagValues.ACCOUNTS: AccountsApi,
+        TagValues.BLOCKS: BlocksApi,
         TagValues.COINS: CoinsApi,
         TagValues.COLLECTIONS: CollectionsApi,
-        TagValues.DEFAULT: DefaultApi,
         TagValues.NFTS: NftsApi,
         TagValues.TRANSACTIONS: TransactionsApi,
         TagValues.WALLETS: WalletsApi,
@@ -25,9 +25,9 @@ TagToApi = typing_extensions.TypedDict(
 tag_to_api = TagToApi(
     {
         TagValues.ACCOUNTS: AccountsApi,
+        TagValues.BLOCKS: BlocksApi,
         TagValues.COINS: CoinsApi,
         TagValues.COLLECTIONS: CollectionsApi,
-        TagValues.DEFAULT: DefaultApi,
         TagValues.NFTS: NftsApi,
         TagValues.TRANSACTIONS: TransactionsApi,
         TagValues.WALLETS: WalletsApi,
