@@ -26,6 +26,10 @@ from openapi_evm_api.apis.paths.erc20_metadata import Erc20Metadata
 from openapi_evm_api.apis.paths.erc20_metadata_symbols import Erc20MetadataSymbols
 from openapi_evm_api.apis.paths.erc20_address_allowance import Erc20AddressAllowance
 from openapi_evm_api.apis.paths.erc20_address_transfers import Erc20AddressTransfers
+from openapi_evm_api.apis.paths.erc20_transfers import Erc20Transfers
+from openapi_evm_api.apis.paths.erc20_mints import Erc20Mints
+from openapi_evm_api.apis.paths.erc20_burns import Erc20Burns
+from openapi_evm_api.apis.paths.erc20_approvals import Erc20Approvals
 from openapi_evm_api.apis.paths.address_balance import AddressBalance
 from openapi_evm_api.apis.paths.wallets_balances import WalletsBalances
 from openapi_evm_api.apis.paths.address import Address
@@ -74,6 +78,10 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.ERC20_METADATA_SYMBOLS: Erc20MetadataSymbols,
         PathValues.ERC20_ADDRESS_ALLOWANCE: Erc20AddressAllowance,
         PathValues.ERC20_ADDRESS_TRANSFERS: Erc20AddressTransfers,
+        PathValues.ERC20_TRANSFERS: Erc20Transfers,
+        PathValues.ERC20_MINTS: Erc20Mints,
+        PathValues.ERC20_BURNS: Erc20Burns,
+        PathValues.ERC20_APPROVALS: Erc20Approvals,
         PathValues.ADDRESS_BALANCE: AddressBalance,
         PathValues.WALLETS_BALANCES: WalletsBalances,
         PathValues.ADDRESS: Address,
@@ -123,6 +131,10 @@ path_to_api = PathToApi(
         PathValues.ERC20_METADATA_SYMBOLS: Erc20MetadataSymbols,
         PathValues.ERC20_ADDRESS_ALLOWANCE: Erc20AddressAllowance,
         PathValues.ERC20_ADDRESS_TRANSFERS: Erc20AddressTransfers,
+        PathValues.ERC20_TRANSFERS: Erc20Transfers,
+        PathValues.ERC20_MINTS: Erc20Mints,
+        PathValues.ERC20_BURNS: Erc20Burns,
+        PathValues.ERC20_APPROVALS: Erc20Approvals,
         PathValues.ADDRESS_BALANCE: AddressBalance,
         PathValues.WALLETS_BALANCES: WalletsBalances,
         PathValues.ADDRESS: Address,
